def read_command_line(objectstring='requested distribution'):
    from argparse import ArgumentParser as AP
    from argparse import FileType

    parser = AP(description=f"Plot the {objectstring} from the RMT-\
produced files. Note that if an input.conf file cannot be found in either the default \
directory (../) or the directory supplied by the -d option then the {objectstring} \
cannot be computed")

    parser.add_argument('file', type=FileType('r'),
                        help='OuterWave_momentum/density file generated by reform')
    parser.add_argument('-d', '--dir', help='RMT calculation root directory',
                        default="../")
    parser.add_argument('-o', '--output', type=str,
                        help=f'Output the {objectstring} to named file',
                        default=None)
    parser.add_argument('--plot', '-p', action='store_true', help='display plot')
    parser.add_argument('--normalise_bar', '-nb', action='store_true', help='normalise the colour bar scale')
    parser.add_argument('--log_scale', '-l', action='store_true', help='plot on a log (base 10) scale')
    parser.add_argument('--rmax', type=float, help='Set maximum radial value for plot',
                        default=None)

    return parser


def momentum_command_line():
    parser = read_command_line('momentum distribution')
    parser.add_argument('--rskip', '-r', type=int,
                        help='(int) size of rskip to use in a.u.', default=200)
    return parser


def density_command_line():
    parser = read_command_line('electron density')
    parser.add_argument('--rmatr', '-r', type=float,
                        help='(float) size of rmatrix boundary in a.u.',
                        default=20.0)
    return parser


def select_command_line(objectstring):
    """set appropriate switches for each choice of objectstring"""
    if objectstring == 'momentum distribution':
        parser = momentum_command_line()
    elif objectstring == 'electron density':
        parser = density_command_line()
    else:
        parser = read_command_line(objectstring)
    return (parser)


def set_default_output_file(args, objectstring):
    """If no output/plot is specified, output to file"""
    if not args.plot and not args.output:
        args.output = f"{objectstring.replace(' ','_')}.png"
    return args


def get_command_line(objectstring='requested distribution'):
    args = select_command_line(objectstring).parse_args()
    return set_default_output_file(args)
